"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from supertone.utils import FieldMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class GetVoiceUsageRequestTypedDict(TypedDict):
    start_date: str
    r"""The start date in YYYY-MM-DD format."""
    end_date: str
    r"""The end date in YYYY-MM-DD format."""


class GetVoiceUsageRequest(BaseModel):
    start_date: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The start date in YYYY-MM-DD format."""

    end_date: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The end date in YYYY-MM-DD format."""
