"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getapicharacterresponsedata import (
    GetAPICharacterResponseData,
    GetAPICharacterResponseDataTypedDict,
)
from supertone.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetAPICharacterListResponseTypedDict(TypedDict):
    items: List[GetAPICharacterResponseDataTypedDict]
    r"""List of character items"""
    total: float
    r"""Total number of available characters (might be approximate or removed in future)"""
    next_page_token: NotRequired[str]
    r"""Token for fetching the next page of results. Undefined if no more pages."""


class GetAPICharacterListResponse(BaseModel):
    items: List[GetAPICharacterResponseData]
    r"""List of character items"""

    total: float
    r"""Total number of available characters (might be approximate or removed in future)"""

    next_page_token: Optional[str] = None
    r"""Token for fetching the next page of results. Undefined if no more pages."""
