"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing_extensions import TypedDict


class InternalServerErrorResponseMessageTypedDict(TypedDict):
    r"""Internal server error details"""

    message: str
    r"""Error message"""
    error: str
    r"""Error type"""
    status_code: float
    r"""HTTP status code"""


class InternalServerErrorResponseMessage(BaseModel):
    r"""Internal server error details"""

    message: str
    r"""Error message"""

    error: str
    r"""Error type"""

    status_code: float
    r"""HTTP status code"""
