"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getcustomvoiceresponse import (
    GetCustomVoiceResponse,
    GetCustomVoiceResponseTypedDict,
)
from supertone.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetCustomVoiceListResponseTypedDict(TypedDict):
    items: List[GetCustomVoiceResponseTypedDict]
    r"""List of custom voice items"""
    total: float
    r"""Total number of available custom voices"""
    next_page_token: NotRequired[str]
    r"""Token for fetching the next page of results. A valid non-negative integer string (e.g., \"10\", \"20\"). Null if no more pages."""


class GetCustomVoiceListResponse(BaseModel):
    items: List[GetCustomVoiceResponse]
    r"""List of custom voice items"""

    total: float
    r"""Total number of available custom voices"""

    next_page_token: Optional[str] = None
    r"""Token for fetching the next page of results. A valid non-negative integer string (e.g., \"10\", \"20\"). Null if no more pages."""
