"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing_extensions import TypedDict


class APISampleDataTypedDict(TypedDict):
    language: str
    r"""Language of the sample"""
    style: str
    r"""Style of the sample"""
    model: str
    r"""Model of the sample"""
    url: str
    r"""URL to the sample audio file"""


class APISampleData(BaseModel):
    language: str
    r"""Language of the sample"""

    style: str
    r"""Style of the sample"""

    model: str
    r"""Model of the sample"""

    url: str
    r"""URL to the sample audio file"""
