"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getusageresponsev1data import (
    GetUsageResponseV1Data,
    GetUsageResponseV1DataTypedDict,
)
from supertone.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class GetUsageListV1ResponseTypedDict(TypedDict):
    usages: List[GetUsageResponseV1DataTypedDict]


class GetUsageListV1Response(BaseModel):
    usages: List[GetUsageResponseV1Data]
