"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing_extensions import TypedDict


class CreateCustomVoiceResponseTypedDict(TypedDict):
    voice_id: str
    r"""Unique identifier for the created voice"""


class CreateCustomVoiceResponse(BaseModel):
    voice_id: str
    r"""Unique identifier for the created voice"""
